% Auto-generated chapter 20 for muslim
% Hadiths in this chapter: 30

\hadithdefcmd{muslim}{3770}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ فَكَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَ الْعَبْدِ قُوِّمَ عَلَيْهِ قِيمَةَ الْعَدْلِ فَأُعْطِيَ شُرَكَاؤُهُ حِصَصَهُمْ وَعَتَقَ عَلَيْهِ الْعَبْدُ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ‏"‏ ‏.‏\hadithno{3770}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger may peace be upon him) as saying:If anyone emancipates his share ina slave and has enough money to pay the full price for him, a fair price for the slave should be fixed, his partners given their shares, and the slave be thus emancipated, otherwise he is emancipated only to the extent of the first man's share}}
\hadithdefcmd{muslim}{3771}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ، الأَيْلِيُّ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، بِمَعْنَى حَدِيثِ مَالِكٍ عَنْ نَافِعٍ.‏\hadithno{3771}\hadithtrans{This hadith has been reported on the authority of Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{3772}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِي الْمَمْلُوكِ بَيْنَ الرَّجُلَيْنِ فَيُعْتِقُ أَحَدُهُمَا قَالَ ‏ "‏ يَضْمَنُ‏"‏ ‏.‏\hadithno{3772}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The slave who is jointly owned by two persons, and is emancipated by one of them, (this one) has liability (upon him to secure complete freedom for that slave)}}
\hadithdefcmd{muslim}{3773}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِقْصًا لَهُ فِي عَبْدٍ فَخَلاَصُهُ فِي مَالِهِ إِنْ كَانَ لَهُ مَالٌ فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ اسْتُسْعِيَ الْعَبْدُ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3773}\hadithtrans{Abu Huraira (Allah be pleased witli him) reported Allah's Prophet (ﷺ) as saying:If anyone emancipates a share in a slave, he is to be completely emancipated if he has money; but if he has none, the slave will be required to work to pay for his freedom, but must not be over-burhened}}
\hadithdefcmd{muslim}{3774}{وَحَدَّثَنَاهُ عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنْ سَعِيدِ بْنِ، أَبِي عَرُوبَةَ بِهَذَا الإِسْنَادِ وَزَادَ ‏ "‏ إِنْ لَمْ يَكُنْ لَهُ مَالٌ قُوِّمَ عَلَيْهِ الْعَبْدُ قِيمَةَ عَدْلٍ ثُمَّ يُسْتَسْعَى فِي نَصِيبِ الَّذِي لَمْ يُعْتِقْ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3774}\hadithtrans{This hadith has been narrated on the authority of Sa'id b. Abu 'Aruba with the same chain of transmitters but with the addition:" If he (one of the joint owners emancipating the slave) has not (enough) money (to secure freedom for the other half) a fair price for the slave should be fixed, and he will be required to work to pay for his freedom, but must not be over-burdened}}
\hadithdefcmd{muslim}{3775}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ بِهَذَا الإِسْنَادِ بِمَعْنَى حَدِيثِ ابْنِ أَبِي عَرُوبَةَ وَذَكَرَ فِي الْحَدِيثِ قُوِّمَ عَلَيْهِ قِيمَةَ عَدْلٍ\hadithno{3775}\hadithtrans{A hadith like this is reported on the authority of the same chain of transmitters but with a slight change of words}}
\hadithdefcmd{muslim}{3776}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، جَارِيَةً تُعْتِقُهَا فَقَالَ أَهْلُهَا نَبِيعُكِهَا عَلَى أَنَّ وَلاَءَهَا لَنَا ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَمْنَعُكِ ذَلِكَ فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{3776}\hadithtrans{Ibn Umar reported that 'A'isha decided to buy a slave-girl and then set her free, but her masters said:We are prepared to sell her to you on the condition that her right of inheritance would vest with you. She (Hadrat A'isha) made a mention of that to Allah's Messenger (ﷺ) whereupon he said: This should not stand in your way. The right of inheritance vests in one who emancipates}}
\hadithdefcmd{muslim}{3777}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ بَرِيرَةَ جَاءَتْ عَائِشَةَ تَسْتَعِينُهَا فِي كِتَابَتِهَا وَلَمْ تَكُنْ قَضَتْ مِنْ كِتَابَتِهَا شَيْئًا فَقَالَتْ لَهَا عَائِشَةُ ارْجِعِي إِلَى أَهْلِكِ فَإِنْ أَحَبُّوا أَنْ أَقْضِيَ عَنْكِ كِتَابَتَكِ وَيَكُونَ وَلاَؤُكِ لِي ‏.‏ فَعَلْتُ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ لأَهْلِهَا فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ فَلْتَفْعَلْ وَيَكُونَ لَنَا وَلاَؤُكِ ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْتَاعِي فَأَعْتِقِي ‏.‏ فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ أُنَاسٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَلَيْسَ لَهُ وَإِنْ شَرَطَ مِائَةَ مَرَّةٍ شَرْطُ اللَّهِ أَحَقُّ وَأَوْثَقُ ‏"‏ ‏.‏\hadithno{3777}\hadithtrans{A'isha (Allah be pjeased with her) reported that Barira came to her in order to seek her help in securing freedom, but she had (so far) paid nothing out of that sum stipulated in the contract. 'A'isba said to her. Go to your family (who owns you), and if they like that I should pay the amount (of the contract) on your behalf (for purchasing your freedom), then I shall have the right in your inheritance. (If they accepted it) I am prepared (to make this payment). Barira made a mention of that to the (members of) her family, but they refused and said:If she (Hadrat 'A'isha) wants to do good to You for the sake of Allah, she may do it, but the right of inheritance will be ours. She (Hadrat 'A'isha) made a mention of that to Allah's Messenger (ﷺ), and he said to her: Buy her, and emancipate her, for the right of inheritance vests with one who emancipates (the slave). Allah's Messenger, may peace be upon him) then stood up and said: What has happened to the people that they lay down conditions which are not (found) in the Book of Allah? And he who laid down a condition not found in the Book of Allah, that is not valid. even if it is laid down hundred times. The condition laid down by Allah is the most weighty and the most valid}}
\hadithdefcmd{muslim}{3778}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، بْنِ الزُّبَيْرِ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ جَاءَتْ بَرِيرَةُ إِلَىَّ فَقَالَتْ يَا عَائِشَةُ إِنِّي كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ فِي كُلِّ عَامٍ أُوقِيَّةٌ ‏.‏ بِمَعْنَى حَدِيثِ اللَّيْثِ وَزَادَ فَقَالَ ‏"‏ لاَ يَمْنَعُكِ ذَلِكِ مِنْهَا ابْتَاعِي وَأَعْتِقِي ‏"‏ ‏.‏ وَقَالَ فِي الْحَدِيثِ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{3778}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported:Barira came to me and said: 'A'isha, I have entered into contract for securing freedom with my family (who owns me) for nine 'uqiyas (of silver), one 'uqiya every year The rest of the hadith is the same (but with this addition):" This (the problem of the right of inheritance) should not stand in your way. Buy her, and set her free. He said in a hadith: Allah's Messenger (ﷺ) stood up among men, extolled Allah, praised Him, and then said:" for}}
\hadithdefcmd{muslim}{3779}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ، بْنُ عُرْوَةَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ عَلَىَّ بَرِيرَةُ فَقَالَتْ إِنَّ أَهْلِي كَاتَبُونِي عَلَى تِسْعِ أَوَاقٍ فِي تِسْعِ سِنِينَ فِي كُلِّ سَنَةٍ أُوقِيَّةٌ ‏.‏ فَأَعِينِينِي ‏.‏ فَقُلْتُ لَهَا إِنْ شَاءَ أَهْلُكِ أَنْ أَعُدَّهَا لَهُمْ عَدَّةً وَاحِدَةً وَأُعْتِقَكِ وَيَكُونَ الْوَلاَءُ لِي فَعَلْتُ ‏.‏ فَذَكَرَتْ ذَلِكَ لأَهْلِهَا فَأَبَوْا إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ فَأَتَتْنِي فَذَكَرَتْ ذَلِكَ قَالَتْ فَانْتَهَرْتُهَا فَقَالَتْ لاَهَا اللَّهِ إِذَا قَالَتْ ‏.‏ فَسَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلَنِي فَأَخْبَرْتُهُ فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا وَاشْتَرِطِي لَهُمُ الْوَلاَءَ فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ فَفَعَلْتُ - قَالَتْ - ثُمَّ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشِيَّةً فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَمَا بَالُ أَقْوَامٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَا كَانَ مِنْ شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ فَهُوَ بَاطِلٌ وَإِنْ كَانَ مِائَةَ شَرْطٍ كِتَابُ اللَّهِ أَحَقُّ وَشَرْطُ اللَّهِ أَوْثَقُ مَا بَالُ رِجَالٍ مِنْكُمْ يَقُولُ أَحَدُهُمْ أَعْتِقْ فُلاَنًا وَالْوَلاَءُ لِي إِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{3779}\hadithtrans{A'isha (Allah be pleased with her) reported:Barira came to me and said: My family (owners) have made contract with me (for granting freedom) for nine 'uqiyas (of silver) payable in nine years, one 'uqiya every year. Help me (in making this payment). I said to her: If your family so desires, I am prepared to make them the full payment in one instalment, and thus secure freedom for you, but the right of inheritance will vest in me, if I do so. She (Barira) made a mention of that to her family, but they refused (except) on the condition that the right of inheritance would vest in them. She came to me and made mention of if She ('A'isha) said: I scolded her. She (Barira) said: By Allah, it is not possible (they will never agree to it). And as she was saying it, Allah's messenger (ﷺ) heard, and he asked me, I informed him and he said: Buy her and emancipate her, and let the right of inherit- ance vest in them, for they cannot claim it (rightfully) since the right of inherritance vests with one who emancipates (the slave; therefore, these people have no right to lay such false claims). And I did so. She ('A'isha) said: Then Allah's Messenger (ﷺ) delivered a sermon in the evening. He extolled Allah and praised Him with what He deserves, and then said afterwards,: What has happened to the people that they lay down conditions which are not found in the Book of Allah? And the condition which is not found in the Book of Allah is invalid, even if its number is one hundred. The Book of Allah is more true (than any other deed) and the condition laid down by Allah is more binding (than any other condition). What has happened to the people among you that someone among you says:" Emancipate so and so, but the right of inheritance vests in me"? Verily, the right of inheritance vests in one who emancipates}}
\hadithdefcmd{muslim}{3780}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ أَبِي أُسَامَةَ غَيْرَ أَنَّ فِي، حَدِيثِ جَرِيرٍ قَالَ وَكَانَ زَوْجُهَا عَبْدًا فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَارَتْ نَفْسَهَا وَلَوْ كَانَ حُرًّا لَمْ يُخَيِّرْهَا ‏.‏ وَلَيْسَ فِي حَدِيثِهِمْ ‏ "‏ أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{3780}\hadithtrans{Hisham b. 'Urwa narrated a hadith like this with the same chain of trans- mitters except (with this change) that in the hadith transmitted on the authority of jartr (the words are):Her (Barira's) husband was a slave, so Allah's Messenger (ﷺ) gave her the option (either to retain her matrimonial relation with her husband or sever it off). She opted to break off (and secure freedom for her even from the matrimonial alliance). And if he were free he would not have given her the option. In the hadith narrated on the authority (of this chain of transmitters) these words are not found: Amma ba'du}}
\hadithdefcmd{muslim}{3781}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ قَضِيَّاتٍ أَرَادَ أَهْلُهَا أَنْ يَبِيعُوهَا وَيَشْتَرِطُوا وَلاَءَهَا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ قَالَتْ وَعَتَقَتْ فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَارَتْ نَفْسَهَا ‏.‏ قَالَتْ وَكَانَ النَّاسُ يَتَصَدَّقُونَ عَلَيْهَا وَتُهْدِي لَنَا ‏.‏ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ وَهُوَ لَكُمْ هَدِيَّةٌ فَكُلُوهُ ‏"‏ ‏.‏\hadithno{3781}\hadithtrans{Abd al-Rahman b. al. Qasim reported on the authority of his father:'A'isha (Allah be pleased with her) said: There were three issues which were clarified in case of Barira: her owners had decided to sell her on the condition that the right of her inheritance would vest with them. She ('A'isha) said: I made a mention of that to Allah's Apostle (ﷺ) and he said: Buy her and emancipate her, for verily the right of inheritance vests with one who emancipates. She said that she emancipated (her) and Allah's Messenger (ﷺ) gave her the option (either to retain her matrimonial alliance or break it after emancipation). She (taking advantage of the option) opted for herself (the severing of matrimonial alliance). 'A'isha said: The people used to give her charity and she gave us that as gift. I made a mention of it to Allah's Apostle (ﷺ), whereupon he said: That is charity for her but gift for you, so take that}}
\hadithdefcmd{muslim}{3782}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏.‏ أَنَّهَا اشْتَرَتْ بَرِيرَةَ مِنْ أُنَاسٍ مِنَ الأَنْصَارِ ‏.‏ وَاشْتَرَطُوا الْوَلاَءَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ وَلِيَ النِّعْمَةَ ‏"‏ ‏.‏ وَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ زَوْجُهَا عَبْدًا وَأَهْدَتْ لِعَائِشَةَ لَحْمًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ صَنَعْتُمْ لَنَا مِنْ هَذَا اللَّحْمِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{3782}\hadithtrans{A'isha (Allah's be pleased with her) reported that she had bought Barira from the people of Ansar, but they laid down the condition that the right of inheritance (would vest in them), whereupon Allah's Messenger (ﷺ) said:The right of inheritance vests with one who shows favour (who emancipates) and Allah's Messenger (may peacebe upon him) gave her the choice (either to retain) her matrimonial alliance or break it). Her husband was a slave. She (Barira also) gave 'A'isha some meat as gift. Allah's Messenger (ﷺ) said: I wish you could prepare (cook) for us out of this meat. 'A'isha said, It has been given as charity to Barira, whereupon he said: That is charity for her and gift for us}}
\hadithdefcmd{muslim}{3783}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَ، الرَّحْمَنِ بْنَ الْقَاسِمِ قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ لِلْعِتْقِ فَاشْتَرَطُوا وَلاَءَهَا فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَأُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم لَحْمٌ فَقَالُوا لِلنَّبِيِّ صلى الله عليه وسلم هَذَا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَهُوَ لَنَا هَدِيَّةٌ ‏"‏ ‏.‏ وَخُيِّرَتْ ‏.‏ فَقَالَ عَبْدُ الرَّحْمَنِ وَكَانَ زَوْجُهَا حُرًّا ‏.‏ قَالَ شُعْبَةُ ثُمَّ سَأَلْتُهُ عَنْ زَوْجِهَا فَقَالَ لاَ أَدْرِي ‏.‏\hadithno{3783}\hadithtrans{A'isha (Allah be pleased with her) reported:She wanted to buy Barira with a view to emancipating her. They (the sellers) laid down the condition that the right of inheritance would vest (with them). She (Hadrat 'A'isha) made a mention of that to Allah's Messenger (ﷺ), whereupon he said: Buy her and emancipate her for the right of inheritance vests with one who emancipates. Allah's Messenger (ﷺ) was given meat as gift. They (his Companions) said to Allah's Apostle (ﷺ): This was given as charity to Barira, whereupon he said: That is charity for her but gift for us. And she was given option (to retain her matrimonial alliance or to break it). Abd al-Rahman said: Her husband was a free man. Shu'ba said: I then asked him (one of the narrators) about Barira's husband (whether he had been a free mart or a slave), whereupon he said: I do not know}}
\hadithdefcmd{muslim}{3784}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3784}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{3785}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ أَبِي هِشَامٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُغِيرَةُ بْنُ سَلَمَةَ الْمَخْزُومِيُّ، وَأَبُو هِشَامٍ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ زَوْجُ بَرِيرَةَ عَبْدًا ‏.‏\hadithno{3785}\hadithtrans{A'isha reported that the husband of Barira was a slave}}
\hadithdefcmd{muslim}{3786}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ رَبِيعَةَ بْنِ أَبِي، عَبْدِ الرَّحْمَنِ عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ خُيِّرَتْ عَلَى زَوْجِهَا حِينَ عَتَقَتْ وَأُهْدِيَ لَهَا لَحْمٌ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْبُرْمَةُ عَلَى النَّارِ فَدَعَا بِطَعَامٍ فَأُتِيَ بِخُبْزٍ وَأُدُمٍ مِنْ أُدُمِ الْبَيْتِ فَقَالَ ‏"‏ أَلَمْ أَرَ بُرْمَةً عَلَى النَّارِ فِيهَا لَحْمٌ ‏"‏ ‏.‏ فَقَالُوا بَلَى يَا رَسُولَ اللَّهِ ذَلِكَ لَحْمٌ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ فَكَرِهْنَا أَنْ نُطْعِمَكَ مِنْهُ ‏.‏ فَقَالَ ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ وَهُوَ مِنْهَا لَنَا هَدِيَّةٌ ‏"‏ ‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم فِيهَا ‏"‏ إِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{3786}\hadithtrans{A'isha (Allah be pleased with her). the wife of Allah's Apostle (may Peace be upon him) said:Three are the Sunan (usages) (that we came to know in case of Bairara). She was given option in regard to her husband when she was emancipated. Sbe was given meat as charity. Allah's Messenger (way peace be upon him) visited me when an earthen pot with meat in it was placed on the fire. He asked for food and be was given bread with ordinary meat (usually cooked in the) house. Thereupon he (Allah's Messenger) said: Don't I see the earthen pot on fire with meat in it? They said: Yes. Allah's Messenger, there is meat in it which was given as charity to Barira. We did not deem it advisable that we should give you that to eat, whereupon he said: It is charity for her, but it is gift for us. Allah's Apostle (ﷺ) also said: The right of inheritance vests with one who emancipates}}
\hadithdefcmd{muslim}{3787}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنِي سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَرَادَتْ عَائِشَةُ أَنْ تَشْتَرِيَ، جَارِيَةً تُعْتِقُهَا فَأَبَى أَهْلُهَا إِلاَّ أَنْ يَكُونَ لَهُمُ الْوَلاَءُ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَمْنَعُكِ ذَلِكِ فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{3787}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:'A'isha (Allah be pleated with her) thought of buying a slave-girl and emancipating her, but her owners refused to (sell her but on the condition) that the right of inheritance would vest in them. She made a mention of that to Allah's Messenger (ﷺ). whereupon he said: Let this (condition) not stand in your way for the right of inheritance vests with one who emancipates}}
\hadithdefcmd{muslim}{3788}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏ قَالَ مُسْلِمٌ النَّاسُ كُلُّهُمْ عِيَالٌ عَلَى عَبْدِ اللَّهِ بْنِ دِينَارٍ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{3788}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (may peace he upon him) forbade the selling and making a gift of the right of inheritance of a slave. Imam Muslim said:All the persons depend upon Abdullah b. Dinar in regard to this hadith}}
\hadithdefcmd{muslim}{3789}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - كُلُّ هَؤُلاَءِ عَنْ عَبْدِ اللَّهِ بْنِ، دِينَارٍ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ الثَّقَفِيَّ لَيْسَ فِي حَدِيثِهِ عَنْ عُبَيْدِ اللَّهِ إِلاَّ الْبَيْعُ وَلَمْ يَذْكُرِ الْهِبَةَ ‏.‏\hadithno{3789}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar (Allah be pleased with them) through another chain of transmitters but with this change that in tba hadith narrated by al-Thaqafi from Ubaidullah there is only a mention of selling (or right of inheritance, al-Wala' ) but not that of making a gift}}
\hadithdefcmd{muslim}{3790}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَتَبَ النَّبِيُّ صلى الله عليه وسلم عَلَى كُلِّ بَطْنٍ عُقُولَهُ ثُمَّ كَتَبَ ‏ "‏ أَنَّهُ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَتَوَالَى مَوْلَى رَجُلٍ مُسْلِمٍ بِغَيْرِ إِذْنِهِ ‏"‏ ‏.‏ ثُمَّ أُخْبِرْتُ أَنَّهُ لَعَنَ فِي صَحِيفَتِهِ مَنْ فَعَلَ ذَلِكَ ‏.‏\hadithno{3790}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported that Allah's Apostle (ﷺ) made it obligatory for every tribe (the payment) of blood-wit; he then also made it explicit that it is not permissible for a Muslim to make himself the ally (of the slave emancipated by another) Muslim without his permission. He (the narrator further added):I was informed that he (the Holy Prophet) cursed the one who did that (and it was recorded) in his Sahifa (in a document)}}
\hadithdefcmd{muslim}{3791}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَوَلَّى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ لاَ يُقْبَلُ مِنْهُ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏\hadithno{3791}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) said:He who takes anyone as his ally without the consent of his previous master, there will be the curse of Allah and that of His angels upon him, and neither, any obligatory act of his nor the supererogatory one will be accepted (by Allah)}}
\hadithdefcmd{muslim}{3793}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ تَوَلَّى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ يَوْمَ الْقِيَامَةِ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ إِبْرَاهِيمُ بْنُ دِينَارٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ وَمَنْ وَالَى غَيْرَ مَوَالِيهِ بِغَيْرِ إِذْنِهِمْ ‏"‏ ‏.‏\hadithno{3793}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:He who took the freed slave as his ally without the consent of his previous master, there is upon him the curse of Allah and that of His angels and that of the whole mankind, and there will not be accepted from him his obligatory acts or supercrogatory acts on the Day of Resurrection. This hadith is narrated through the same chain of transmitters, but with a slight change of words}}
\hadithdefcmd{muslim}{3794}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ خَطَبَنَا عَلِيُّ بْنُ أَبِي طَالِبٍ فَقَالَ مَنْ زَعَمَ أَنَّ عِنْدَنَا، شَيْئًا نَقْرَأُهُ إِلاَّ كِتَابَ اللَّهِ وَهَذِهِ الصَّحِيفَةَ - قَالَ وَصَحِيفَةٌ مُعَلَّقَةٌ فِي قِرَابِ سَيْفِهِ - فَقَدْ كَذَبَ ‏.‏ فِيهَا أَسْنَانُ الإِبِلِ وَأَشْيَاءُ مِنَ الْجِرَاحَاتِ وَفِيهَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْمَدِينَةُ حَرَمٌ مَا بَيْنَ عَيْرٍ إِلَى ثَوْرٍ فَمَنْ أَحْدَثَ فِيهَا حَدَثًا أَوْ آوَى مُحْدِثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ وَمَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوِ انْتَمَى إِلَى غَيْرِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً ‏"‏ ‏.‏\hadithno{3794}\hadithtrans{Ibrahim al-Taimi reported on the authority of his father:'Ali b. Abu Talib (Allah be pleased with him) addressed us and said: He who thinks that we (the members of the Prophet's family) read anything else besides the Book of Allah and this Sahifa (and he said that Sahifa was tied to the scabbard of the sword) tells a lie. (This Sahifa) contains (problems) pertaining to the ages of the camels and (the recompense) of the injuries, and it also records the words of the Prophet (ﷺ): Medina is a sacred territory from 'Ayr to Thaur (it is most probably Uhud). He who innovates (an act or practice) or gives protection to an innovator, there is a curse of Allah and that of His angels and that of the whole humanity upon him. Allah will not accdpt from him (as a recompense) any obligatory act or supererogatory act, and the responsibility of the Muslims is a joint responsibility; even the lowest in rank can undertake the responsibility (on behalf of others), and he who claims anyone else as his father besides his own father or makes one his ally other than the one (who freed him), there is a curse of Allah. that of His angels and that of the wholemankind upon him. Allah will not accept the obligatory act of the supererogatery act (as a recompense) from him}}
\hadithdefcmd{muslim}{3795}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، - وَهُوَ ابْنُ أَبِي هِنْدٍ - حَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبِي حَكِيمٍ، عَنْ سَعِيدِ ابْنِ مَرْجَانَةَ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ رَقَبَةً مُؤْمِنَةً أَعْتَقَ اللَّهُ بِكُلِّ إِرْبٍ مِنْهَا إِرْبًا مِنْهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3795}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:If anyone emancipates a Muslim slave, Allah will set free from Hell an organ of his body for every organ of his (slave's) body}}
\hadithdefcmd{muslim}{3796}{وَحَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ مُحَمَّدِ بْنِ مُطَرِّفٍ أَبِي غَسَّانَ، الْمَدَنِيِّ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ سَعِيدِ ابْنِ مَرْجَانَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ رَقَبَةً أَعْتَقَ اللَّهُ بِكُلِّ عُضْوٍ مِنْهَا عُضْوًا مِنْ أَعْضَائِهِ مِنَ النَّارِ حَتَّى فَرْجَهُ بِفَرْجِهِ ‏"‏ ‏.‏\hadithno{3796}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (may peace benpon him) as saying:He who emancipates a slave, Allah will set free from Hell every limb (of his body) for every limb of his (slave's) body, even his private parts}}
\hadithdefcmd{muslim}{3797}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ الْهَادِ، عَنْ عُمَرَ بْنِ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ سَعِيدِ ابْنِ مَرْجَانَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَعْتَقَ رَقَبَةً مُؤْمِنَةً أَعْتَقَ اللَّهُ بِكُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنَ النَّارِ حَتَّى يُعْتِقَ فَرْجَهُ بِفَرْجِهِ‏"‏ ‏.‏\hadithno{3797}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:I heard Allah's Messenger (ﷺ) as saying: He who emancipates a believing slave. Allah will set free from Fire his every limb for every limb of his (slave's), even his private parts for his}}
\hadithdefcmd{muslim}{3798}{وَحَدَّثَنِي حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عَاصِمٌ، - وَهُوَ ابْنُ مُحَمَّدٍ الْعُمَرِيُّ - حَدَّثَنَا وَاقِدٌ، - يَعْنِي أَخَاهُ - حَدَّثَنِي سَعِيدُ ابْنُ مَرْجَانَةَ، - صَاحِبُ عَلِيِّ بْنِ حُسَيْنٍ - قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرِئٍ مُسْلِمٍ أَعْتَقَ امْرَأً مُسْلِمًا اسْتَنْقَذَ اللَّهُ بِكُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنْهُ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ فَانْطَلَقْتُ حِينَ سَمِعْتُ الْحَدِيثَ مِنْ أَبِي هُرَيْرَةَ فَذَكَرْتُهُ لِعَلِيِّ بْنِ الْحُسَيْنِ فَأَعْتَقَ عَبْدًا لَهُ قَدْ أَعْطَاهُ بِهِ ابْنُ جَعْفَرٍ عَشْرَةَ آلاَفِ دِرْهَمٍ أَوْ أَلْفَ دِينَارٍ ‏.‏\hadithno{3798}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:A Muslim who emancipates a Muslim (slave). Allah will save from Fire every limb of his for every limb (of the slave). Sa'id b. Marjana said: When I heard this hadith from Abu Huraira (Allah be pleased with him), I went away and made a mention of it to 'Ali b. Husain and he at once emancipated the slave for which Ibn ja'far was prepared to pay ten thousand dirhams or one thousand dinars}}
\hadithdefcmd{muslim}{3799}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَجْزِي وَلَدٌ وَالِدًا إِلاَّ أَنْ يَجِدَهُ مَمْلُوكًا فَيَشْتَرِيَهُ فَيُعْتِقَهُ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي شَيْبَةَ ‏"‏ وَلَدٌ وَالِدَهُ ‏"‏ ‏.‏\hadithno{3799}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:A son does not repay what he owes his father unless he buys him (the father) in case he is a slave and then emancipates him. In the narration transmitted by Ibn Abu Shaiba there is a slight change of words}}
\hadithdefcmd{muslim}{3800}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، كُلُّهُمْ عَنْ سُفْيَانَ، عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالُوا ‏ "‏ وَلَدٌ وَالِدَهُ ‏"‏ ‏.‏\hadithno{3800}\hadithtrans{A hadith like this has been narrated on the authority of Suhail with the same chain of transmitters}}
